@@ -81,13 +81,13 @@ nco_ppc_ini /* Set PPC based on user specifications */
   char *sng_fnl=NULL;
 
   /* Join arguments together */
-  sng_fnl=nco_join_sng(ppc_arg, ppc_arg_nbr);
+  sng_fnl=nco_join_sng(ppc_arg,ppc_arg_nbr);
   ppc_lst=nco_arg_mlt_prs(sng_fnl);
 
   if(sng_fnl) sng_fnl=(char *)nco_free(sng_fnl);
 
-  /* jm fxm use more descriptive name than i---what does i count? */
-  for(int index=0;(ppc_lst+index)->key;index++, ppc_var_nbr++); /* end loop over i */
+  /* Compute ppc_var_nbr */
+  for(int idx=0;(ppc_lst+idx)->key;idx++,ppc_var_nbr++);
 
   /* PPC "default" specified, set all non-coordinate variables to default first */
   for(ppc_var_idx=0;ppc_var_idx<ppc_var_nbr;ppc_var_idx++){
@@ -224,7 +224,7 @@ nco_ppc_set_dflt /* Set PPC value for all non-coordinate variables for --ppc def
       } /* endif */
     } /* endif */
   } /* endfor */
-} /* end nco_ppc_set_dflt() */
+} /* !nco_ppc_set_dflt() */
 
 void
 nco_ppc_set_var
@@ -333,7 +333,7 @@ nco_ppc_set_var
   } /* endif */
     
   return;
-} /* end nco_ppc_set_var() */
+} /* !nco_ppc_set_var() */
 
 void
 nco_ppc_around /* [fnc] Replace op1 values by their values rounded to decimal precision prc */
@@ -548,7 +548,7 @@ nco_ppc_bitmask /* [fnc] Mask-out insignificant bits of significand */
   
   /* Rounding is currently defined as op1:=bitmask(op1,ppc) */  
   
-  /* This routine implements the Bit Grooming Number of Significant Digits (NSD) algorithm
+  /* This routine implements the BitGrooming Number of Significant Digits (NSD) algorithm
      NSD based on absolute precision, i.e., number of digits in significand and in decimal scientific notation
      DSD based on precision relative to decimal point, i.e., number of digits before/after decimal point
      DSD is more often used colloquially, e.g., "thermometers measure temperature accurate to 1 degree C" 
@@ -576,7 +576,7 @@ nco_ppc_bitmask /* [fnc] Mask-out insignificant bits of significand */
      ncks -C -v ppc_big,ppc_bgr ~/foo.nc
      ncks -s '%16.12e\n' -C -H -v ppc_big,ppc_bgr ~/foo_n34.nc */
   
-  /* IEEE single- and double-precision significands have 24 and 53 bits of precision (prc_bnr)
+  /* IEEE single- and double-precision significands have 24 and 53 bits of total precision (prc_bnr)
      Decimal digits of precision (prc_dcm) obtained via prc_dcm=prc_bnr*ln(2)/ln(10) = 7.22 and 15.95, respectively
      Binary "digits" (i.e., bits) of precision (prc_bnr) obtained via prc_bnr=prc_dcm*ln(10)/ln(2) */
   
@@ -588,7 +588,7 @@ nco_ppc_bitmask /* [fnc] Mask-out insignificant bits of significand */
   const double dgt_per_bit_dgr=0.301029996; /* 0.301 [frc] Decimal digits per bit of precision = log10(2) used in DigitRound algorithm and code */
   
   const int bit_xpl_nbr_sgn_flt=23; /* [nbr] Bits 0-22 of SP significands are explicit. Bit 23 is implicitly 1. */
-  const int bit_xpl_nbr_sgn_dbl=53; /* [nbr] Bits 0-52 of DP significands are explicit. Bit 53 is implicitly 1. */
+  const int bit_xpl_nbr_sgn_dbl=52; /* [nbr] Bits 0-51 of DP significands are explicit. Bit 52 is implicitly 1. */
   //const int ieee_xpn_fst_flt=127; /* [nbr] IEEE "exponent bias" = actual exponent minus stored exponent */
   //const int ieee_xpn_fst_dbl=1023; /* [nbr] IEEE "exponent bias" = actual exponent minus stored exponent */
   
@@ -609,7 +609,7 @@ nco_ppc_bitmask /* [fnc] Mask-out insignificant bits of significand */
     }; /* !mnt_log10_tbl_dgr */
 #if 0 /* Not currently used */
   const double mnt_log10_tbl_gbr[5][2]=
-    { /* NB: Granular Bit Groom extends Digit Round tabular precision from 9 to 15 digits */
+    { /* NB: Granular BitGroom extends Digit Round tabular precision from 9 to 15 digits */
      {0.6,-dgt_per_bit}, /* Approximate log10(mnt) for mantissas in [0.5,0.6) as log10(0.5) = log10(2^(-1)) = -log10(2) = -dgt_per_bit = -0.301 */
      {0.7,-0.221848749616356}, /* Approximate log10(mnt) for mantissas in [0.6,0.7) as log10(0.6) = -0.222 */
      {0.8,-0.154901959985743}, /* Approximate log10(mnt) for mantissas in [0.7,0.8) as log10(0.7) = -0.155 */
@@ -712,7 +712,12 @@ nco_ppc_bitmask /* [fnc] Mask-out insignificant bits of significand */
     //prc_bnr_xpl_rqr=prc_bnr_ceil;
     prc_bnr_xpl_rqr=prc_bnr_ceil+1;
 
-    if(type == NC_DOUBLE) prc_bnr_xpl_rqr++; /* Seems necessary for double-precision ppc=array(1.234567,1.0e-6,$dmn) */
+    /* 20220219: Bugfix
+       Set bit_xpl_nbr_sgn_dbl=52 not 53 since limits.h/climit DBL_MANT_DIG=53 (which includes implicit bit)
+       No longer need to add an additional bit for NC_DOUBLE quantization:
+       if(type == NC_DOUBLE) prc_bnr_xpl_rqr++; // Seems necessary for double-precision ppc=array(1.234567,1.0e-6,$dmn) 
+    */
+    
     /* 20150128: Hand-tuning shows we can sacrifice one or two more bits for almost all cases
        20150205: However, small integers are an exception. In fact they require two more bits, at least for NSD=1.
        Thus minimum threshold to preserve half of least significant digit (LSD) is prc_bnr_xpl_rqr=prc_bnr_ceil
@@ -924,7 +929,7 @@ nco_ppc_bitmask /* [fnc] Mask-out insignificant bits of significand */
       break;
       /* !DigitRound = DGR */
     case nco_baa_gbr:
-      /* Granular Bit Groom
+      /* Granular BitGroom
 	 Test GBG:
 	 ccc --tst=bnr --flt_foo=8 2> /dev/null | grep "Binary of float"
 	 ncks -O -7 -C -D 1 --baa=4 -v ppc_bgr --ppc default=3 ~/nco/data/in.nc ~/foo.nc
@@ -1154,7 +1159,7 @@ nco_ppc_bitmask /* [fnc] Mask-out insignificant bits of significand */
     case nco_baa_bgr_btr:
     case nco_baa_btr:
       /* Round mantissa, LSBs to zero contributed by Rostislav Kouznetsov 20200711
-	 Round mantissa using floating-point arithmetic, shave LSB using bit-mask
+	 Round mantissa using software emulation of IEEE arithmetic, shave LSB using bit-mask
 	 See figures at https://github.com/nco/nco/pull/199 */
       for(idx=0L;idx<sz;idx++){
 	if(op1.dp[idx] != mss_val_cmp_dbl){
@@ -1265,7 +1270,7 @@ nco_ppc_bitmask_scl /* [fnc] Round input value significand by specified number o
      Code originally from nco_ppc_bitmask() (bitmasking is my signature move)
      Code used in nco_rgr_wgt() when diagnosing whether quadrature weights properly normalized */
 
-  const int bit_xpl_nbr_sgn_dbl=53; /* [nbr] Bits 0-52 of DP significands are explicit. Bit 53 is implicit. */
+  const int bit_xpl_nbr_sgn_dbl=52; /* [nbr] Bits 0-51 of DP significands are explicit. Bit 52 is implicit. */
   double val_rnd; /* [frc] Rounded version of exact value */
   unsigned long int *u64_ptr;
   unsigned long int msk_f64_u64_zro;
@@ -1280,4 +1285,4 @@ nco_ppc_bitmask_scl /* [fnc] Round input value significand by specified number o
   *u64_ptr&=msk_f64_u64_zro;
 
   return val_rnd;
-} /* end nco_ppc_bitmask_scl() */
+} /* !nco_ppc_bitmask_scl() */
